/*
 * dlglohef.c --- load Hershey font dialog
 * 
 * Copyright (c) 2019 Mariano Alvarez Fernandez (malfer@telefonica.net)
 *
 * This file is part of FEdit, a visual font editor for the MGRX font format
 *
 * FEdit is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FEdit is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FEdit. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <grgui.h>
#include <mgrxcolr.h>
#include "fedit.h"

#define COMMAND_OK           1
#define COMMAND_CANCEL       2

GUIDialog *flohedlg = NULL;
GUIGroup *flohego = NULL;

int process_flohedlg_event(void *udata, GrEvent *ev)
{
    GUIDialog *d = (GUIDialog *)udata;
    GUIGroup *go = (GUIGroup *)(d->exdata);

    if (ev->type == GREV_COMMAND) {
        switch (ev->p1) {
            case COMMAND_OK :
                d->result = 1;
               return -1;
            case COMMAND_CANCEL :
                d->result = -1;
                return -1;
        }
    }

    return GUIGroupProcessEvent(go, ev);
}

int FLoheDlgCreate(void)
{
    if (flohedlg) return 1; // dialog already created

    flohego = GUIGroupCreate(12, 0, 0);
    if (flohego == NULL) return 0;
    GUIObjectSetLabel(&(flohego->o[0]), 0,   0,   0, 160, 30, GrNOCOLOR, WEBC_WHITE, "Hersey font name");
    GUIObjectSetEntry(&(flohego->o[1]), 1, 160,   0, 160, 30, WEBC_WHITE, WEBC_BLACK, MAXLEN_FNAME, "");
    GUIObjectSetLabel(&(flohego->o[2]), 2,   0,  40, 160, 30, GrNOCOLOR, WEBC_WHITE, "Max glyphs to load");
    GUIObjectSetEntry(&(flohego->o[3]), 3, 160,  40, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(flohego->o[4]), 4,   0,  80, 160, 30, GrNOCOLOR, WEBC_WHITE, "First dest. glyph");
    GUIObjectSetEntry(&(flohego->o[5]), 5, 160,  80, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(flohego->o[6]), 6,   0, 120, 160, 30, GrNOCOLOR, WEBC_WHITE, "Zoom to apply");
    GUIObjectSetEntry(&(flohego->o[7]), 7, 160, 120, 160, 30, WEBC_WHITE, WEBC_BLACK, 16, "");
    GUIObjectSetLabel(&(flohego->o[8]), 8,   0, 160, 160, 30, GrNOCOLOR, WEBC_WHITE, "Line thick");
    GUIObjectSetEntry(&(flohego->o[9]), 9, 160, 160, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetButton(&(flohego->o[10]), 10,  10, 210, 140, 40, WEBC_GREEN, WEBC_WHITE, "Ok", COMMAND_OK, 0, 0);
    GUIObjectSetButton(&(flohego->o[11]), 11, 170, 210, 140, 40, WEBC_GREEN, WEBC_WHITE, "Cancel", COMMAND_CANCEL, 0, 0);
    GUIGroupSetSelected(flohego, 1, 0);

    flohedlg = GUIGroupDialogCreate("Load Font from Hershey data",
                                    flohego, process_flohedlg_event);
    if (flohedlg == NULL) {
        GUIGroupDestroy(flohego);
        flohego = NULL;
        return 0;
    }

    return 1;
}

void FLoheDlgDestroy(void)
{
    if (flohedlg) {
        GUIDialogDestroy(flohedlg);
        flohedlg = NULL;
    }
    if (flohego) {
        GUIGroupDestroy(flohego);
        flohego = NULL;
    }
}

void FLoheDlgSetData(char *fname, int maxglyph,
                     int fdglyph, double zoom, int thick)
{
    char s[121];
    
    if (!flohedlg) return;

    GUIGroupSetText(flohego, 1, fname);
    sprintf(s, "%d", maxglyph);
    GUIGroupSetText(flohego, 3, s);
    sprintf(s, "%d", fdglyph);
    GUIGroupSetText(flohego, 5, s);
    sprintf(s, "%f", zoom);
    GUIGroupSetText(flohego, 7, s);
    sprintf(s, "%d", thick);
    GUIGroupSetText(flohego, 9, s);
}

void FLoheDlgGetData(char *fname, int *maxglyph,
                     int *fdglyph, double *zoom, int *thick)
{
    char *s;

    if (!flohedlg) return;

    s = GUIGroupGetText(flohego, 1, GrGetChrtypeForUserEncoding());
    strcpy(fname, s);
    free(s);
    s = GUIGroupGetText(flohego, 3, GrGetChrtypeForUserEncoding());
    *maxglyph = atoi(s);
    free(s);
    s = GUIGroupGetText(flohego, 5, GrGetChrtypeForUserEncoding());
    *fdglyph = atoi(s);
    free(s);
    s = GUIGroupGetText(flohego, 7, GrGetChrtypeForUserEncoding());
    *zoom = atof(s);
    free(s);
    s = GUIGroupGetText(flohego, 9, GrGetChrtypeForUserEncoding());
    *thick = atoi(s);
    free(s);
}

int FLoheDlgRun(void)
{
    if (!flohedlg) return -1; 

    flohedlg->result = -1;
    GUIDialogRun(flohedlg);
    return flohedlg->result;
}

