/*
 * dlgrrang.c --- reload range dialog
 * 
 * Copyright (c) 2019 Mariano Alvarez Fernandez (malfer@telefonica.net)
 *
 * This file is part of FEdit, a visual font editor for the MGRX font format
 *
 * FEdit is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FEdit is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FEdit. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <grgui.h>
#include <mgrxcolr.h>
#include "fedit.h"

#define COMMAND_OK           1
#define COMMAND_CANCEL       2

GUIDialog *rrangdlg = NULL;
GUIGroup *rranggo = NULL;

int process_rrangdlg_event(void *udata, GrEvent *ev)
{
    GUIDialog *d = (GUIDialog *)udata;
    GUIGroup *go = (GUIGroup *)(d->exdata);

    if (ev->type == GREV_COMMAND) {
        switch (ev->p1) {
            case COMMAND_OK :
                d->result = 1;
               return -1;
            case COMMAND_CANCEL :
                d->result = -1;
                return -1;
        }
    }

    return GUIGroupProcessEvent(go, ev);
}

int RRangDlgCreate(void)
{
    if (rrangdlg) return 1; // dialog already created

    rranggo = GUIGroupCreate(6, 0, 0);
    if (rranggo == NULL) return 0;
    GUIObjectSetLabel(&(rranggo->o[0]), 0,   0,   0, 160, 30, GrNOCOLOR, WEBC_WHITE, "First glyph");
    GUIObjectSetEntry(&(rranggo->o[1]), 1, 160,   0, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(rranggo->o[2]), 2,   0,  40, 160, 30, GrNOCOLOR, WEBC_WHITE, "Last glyph");
    GUIObjectSetEntry(&(rranggo->o[3]), 3, 160,  40, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetButton(&(rranggo->o[4]), 4,  10, 90, 140, 40, WEBC_GREEN, WEBC_WHITE, "Ok", COMMAND_OK, 0, 0);
    GUIObjectSetButton(&(rranggo->o[5]), 5, 170, 90, 140, 40, WEBC_GREEN, WEBC_WHITE, "Cancel", COMMAND_CANCEL, 0, 0);
    GUIGroupSetSelected(rranggo, 1, 0);

    rrangdlg = GUIGroupDialogCreate("Reload glyph range",
                                    rranggo, process_rrangdlg_event);
    if (rrangdlg == NULL) {
        GUIGroupDestroy(rranggo);
        rranggo = NULL;
        return 0;
    }

    return 1;
}

void RRangDlgDestroy(void)
{
    if (rrangdlg) {
        GUIDialogDestroy(rrangdlg);
        rrangdlg = NULL;
    }
    if (rranggo) {
        GUIGroupDestroy(rranggo);
        rranggo = NULL;
    }
}

void RRangDlgSetData(int fglyph, int lglyph)
{
    char s[121];
    
    if (!rrangdlg) return;

    sprintf(s, "%d", fglyph);
    GUIGroupSetText(rranggo, 1, s);
    sprintf(s, "%d", lglyph);
    GUIGroupSetText(rranggo, 3, s);
}

void RRangDlgGetData(int *fglyph, int *lglyph)
{
    char *s;

    if (!rrangdlg) return;

    s = GUIGroupGetText(rranggo, 1, GrGetChrtypeForUserEncoding());
    *fglyph = atoi(s);
    free(s);
    s = GUIGroupGetText(rranggo, 3, GrGetChrtypeForUserEncoding());
    *lglyph = atoi(s);
    free(s);
}

int RRangDlgRun(void)
{
    if (!rrangdlg) return -1; 

    rrangdlg->result = -1;
    GUIDialogRun(rrangdlg);
    return rrangdlg->result;
}

