/*
 * dlgsavef.c --- save font dialog
 * 
 * Copyright (c) 2019 Mariano Alvarez Fernandez (malfer@telefonica.net)
 *
 * This file is part of FEdit, a visual font editor for the MGRX font format
 *
 * FEdit is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FEdit is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FEdit. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <grgui.h>
#include <mgrxcolr.h>
#include "fedit.h"

#define COMMAND_OK           1
#define COMMAND_CANCEL       2

GUIDialog *fsavedlg = NULL;
GUIGroup *fsavego = NULL;

int process_fsavedlg_event(void *udata, GrEvent *ev)
{
    GUIDialog *d = (GUIDialog *)udata;
    GUIGroup *go = (GUIGroup *)(d->exdata);

    if (ev->type == GREV_COMMAND) {
        switch (ev->p1) {
            case COMMAND_OK :
                d->result = 1;
               return -1;
            case COMMAND_CANCEL :
                d->result = -1;
                return -1;
        }
    }

    return GUIGroupProcessEvent(go, ev);
}

int FSaveDlgCreate(void)
{
    if (fsavedlg) return 1; // dialog already created

    fsavego = GUIGroupCreate(8, 0, 0);
    if (fsavego == NULL) return 0;
    GUIObjectSetLabel(&(fsavego->o[0]), 0,   0,   0, 160, 30, GrNOCOLOR, WEBC_WHITE, "Output filename");
    GUIObjectSetEntry(&(fsavego->o[1]), 1, 160,   0, 160, 30, WEBC_WHITE, WEBC_BLACK, MAXLEN_FNAME, "");
    GUIObjectSetLabel(&(fsavego->o[2]), 2,   0,  40, 160, 30, GrNOCOLOR, WEBC_WHITE, "First glyph");
    GUIObjectSetEntry(&(fsavego->o[3]), 3, 160,  40, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(fsavego->o[4]), 4,   0,  80, 160, 30, GrNOCOLOR, WEBC_WHITE, "Last glyph");
    GUIObjectSetEntry(&(fsavego->o[5]), 5, 160,  80, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetButton(&(fsavego->o[6]), 6,  10, 130, 140, 40, WEBC_GREEN, WEBC_WHITE, "Ok", COMMAND_OK, 0, 0);
    GUIObjectSetButton(&(fsavego->o[7]), 7, 170, 130, 140, 40, WEBC_GREEN, WEBC_WHITE, "Cancel", COMMAND_CANCEL, 0, 0);
    GUIGroupSetSelected(fsavego, 1, 0);

    fsavedlg = GUIGroupDialogCreate("Save Font",
                                    fsavego, process_fsavedlg_event);
    if (fsavedlg == NULL) {
        GUIGroupDestroy(fsavego);
        fsavego = NULL;
        return 0;
    }

    return 1;
}

void FSaveDlgDestroy(void)
{
    if (fsavedlg) {
        GUIDialogDestroy(fsavedlg);
        fsavedlg = NULL;
    }
    if (fsavego) {
        GUIGroupDestroy(fsavego);
        fsavego = NULL;
    }
}

void FSaveDlgSetData(char *output, int fglyph, int lglyph)
{
    char s[121];
    
    if (!fsavedlg) return;

    GUIGroupSetText(fsavego, 1, output);
    sprintf(s, "%d", fglyph);
    GUIGroupSetText(fsavego, 3, s);
    sprintf(s, "%d", lglyph);
    GUIGroupSetText(fsavego, 5, s);
}

void FSaveDlgGetData(char *output, int *fglyph, int *lglyph)
{
    char *s;

    if (!fsavedlg) return;

    s = GUIGroupGetText(fsavego, 1, GrGetChrtypeForUserEncoding());
    strcpy(output, s);
    free(s);
    s = GUIGroupGetText(fsavego, 3, GrGetChrtypeForUserEncoding());
    *fglyph = atoi(s);
    free(s);
    s = GUIGroupGetText(fsavego, 5, GrGetChrtypeForUserEncoding());
    *lglyph = atoi(s);
    free(s);
}

int FSaveDlgRun(void)
{
    if (!fsavedlg) return -1; 

    fsavedlg->result = -1;
    GUIDialogRun(fsavedlg);
    return fsavedlg->result;
}

